AdManagerBannerProvider class

Constructors

AdManagerBannerProvider({required AdSize adSize, required String adManagerBannerAdId, List<String>? keywords, String? contentUrl, List<String>? neighboringContentUrls, Map<String, String>? customTargeting, Map<String, List<String>>? customTargetingLists, bool? nonPersonalizedAds, int? httpTimeoutMillis, String? publisherProvidedId, LocationParams? location, String? mediationExtrasIdentifier, Map<String, String>? extras, void onAdLoaded(Ad)?, dynamic onAdFailedToLoad(Ad, LoadAdError)?, void onAdClosed(Ad)?, void onAdOpened(Ad)?})

Properties

no setter
adManagerBannerAdId String
final
adSize → AdSize
final
available → dynamic
no setter
contentUrl String?
final
customTargeting Map<String, String>?
final
customTargetingLists Map<String, List<String>>?
final
extras Map<String, String>?
final
hashCode int
The hash code for this object.
no setterinherited
httpTimeoutMillis int?
final
keywords List<String>?
final
location → LocationParams?
final
mediationExtrasIdentifier String?
final
neighboringContentUrls List<String>?
final
nonPersonalizedAds bool?
final
onAdClosed ↔ void Function(Ad)?
getter/setter pair
onAdFailedToLoad ↔ dynamic Function(Ad, LoadAdError)?
getter/setter pair
onAdLoaded ↔ void Function(Ad)?
getter/setter pair
onAdOpened ↔ void Function(Ad)?
getter/setter pair
publisherProvidedId String?
final
retries int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
retry() → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited