InterstitialAdsProvider class
Constructors
-
InterstitialAdsProvider({required String interstitialAdId, bool? nonPersonalized = true, Map<
String, String> ? extras, List<String> ? keywords, LocationParams? location, int? httpTimeoutMillis, String? mediationExtrasIdentifier, List<String> ? neighboringContentUrls, String? contentUrl, void onAdLoaded(InterstitialAd)?, void onAdFailedToLoad(LoadAdError)?})
Properties
- available → dynamic
-
no setter
- contentUrl → String?
-
final
-
extras
↔ Map<
String, String> ? -
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- httpTimeoutMillis → int?
-
final
- interstitialAdId → String
-
final
-
keywords
→ List<
String> ? -
final
- location → LocationParams?
-
final
- maxFailedLoadAttempts ↔ int
-
getter/setter pair
- mediationExtrasIdentifier ↔ String?
-
getter/setter pair
-
neighboringContentUrls
↔ List<
String> ? -
getter/setter pair
- nonPersonalized → bool?
-
final
- onAdFailedToLoad ↔ void Function(LoadAdError)?
-
getter/setter pair
- onAdLoaded ↔ void Function(InterstitialAd)?
-
getter/setter pair
- retries ↔ int
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dispose(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
retry(
) → void -
show(
) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited