AndroidSetup class
Constructors
- AndroidSetup(String jsonFilePath)
Properties
- adUnitIdPath → String
-
final
- appLevelGradle → String
-
final
- applicationId → String
-
final
- appLovinSdkKey → String
-
final
- gradlePropertiesPath → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- jsonFilePath → String
-
final
- mainPath → String
-
final
- pathManifest → String
-
final
- plistPath → String
-
final
- podfileAdColonyImport → String
-
final
- podfileAppLovinImport → String
-
final
- podfileFacebookImport → String
-
final
- podfileGoogleImport → String
-
final
- podfilePath → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
process(
) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited